@@ -9,7 +9,7 @@ use fields qw( stderr );
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.9 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.10 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -31,13 +31,11 @@ sub new
     return $self;
 }
 
-sub log
+sub log_message
 {
     my Log::Dispatch::Screen $self = shift;
     my %params = @_;
 
-    return unless $self->_should_log($params{level});
-
     if ($self->{stderr})
     {
 	print STDERR $params{message};
@@ -100,10 +98,26 @@ Indicates whether or not logging information should go to STDERR.  If
 false, logging information is printed to STDOUT instead.  This
 defaults to true.
 
-=item * log( level => $, message => $ )
+=item -- callbacks( \& or [ \&, \&, ... ] )
 
-Sends a message if the level is greater than or equal to the object's
-minimum level.
+This parameter may be a single subroutine reference or an array
+reference of subroutine references.  These callbacks will be called in
+the order they are given and passed a hash containing the following keys:
+
+ ( message => $log_message )
+
+It's a hash in case I need to add parameters in the future.
+
+The callbacks are expected to modify the message and then return a
+single scalar containing that modified message.  These callbacks will
+be called when either the C<log> or C<log_to> methods are called and
+will only be applied to a given message once.
+
+=item * log_message( message => $ )
+
+Sends a message to the appropriate output.  Generally this shouldn't
+be called directly but should be called through the C<log()> method
+(in Log::Dispatch::Output).
 
 =back
 
