@@ -14,7 +14,7 @@ require 'syslog.ph';
 
 use vars qw[ $VERSION ];
 
-$VERSION = sprintf "%d.%03d", q$Revision: 1.10 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.11 $ =~ /: (\d+)\.(\d+)/;
 
 1;
 
@@ -59,13 +59,11 @@ sub _init
     Sys::Syslog::setlogsock $self->{socket};
 }
 
-sub log
+sub log_message
 {
     my Log::Dispatch::Syslog $self = shift;
     my %params = @_;
 
-    return unless $self->_should_log($params{level});
-
     my $pri = $self->_level_as_number($params{level});
 
     Sys::Syslog::openlog($self->{ident}, $self->{logopt}, $self->{facility});
@@ -144,6 +142,27 @@ Valid options are 'auth', 'authpriv', 'cron', 'daemon', 'kern',
 Tells what type of socket to use for sending syslog messages.  Valid
 options are 'unix' or 'inet'.  Defaults to 'inet'.
 
+=item -- callbacks( \& or [ \&, \&, ... ] )
+
+This parameter may be a single subroutine reference or an array
+reference of subroutine references.  These callbacks will be called in
+the order they are given and passed a hash containing the following keys:
+
+ ( message => $log_message )
+
+It's a hash in case I need to add parameters in the future.
+
+The callbacks are expected to modify the message and then return a
+single scalar containing that modified message.  These callbacks will
+be called when either the C<log> or C<log_to> methods are called and
+will only be applied to a given message once.
+
+=item * log_message( message => $ )
+
+Sends a message to the appropriate output.  Generally this shouldn't
+be called directly but should be called through the C<log()> method
+(in Log::Dispatch::Output).
+
 =back
 
 =head1 AUTHOR
