@@ -6,7 +6,7 @@
 # Change 1..1 below to 1..last_test_to_print .
 # (It may become useful if the test is moved to ./t subdirectory.)
 
-BEGIN { $| = 1; print "1..16\n"; }
+BEGIN { $| = 1; print "1..106\n"; }
 END {print "not ok 1\n" unless $main::loaded;}
 
 use strict;
@@ -309,6 +309,86 @@ Screen:
 	    "Log::Dispatch callback did not reverse and uppercase text as expected: $text\n" );
 }
 
+# 17:  Log::Dispatch::Output single callback
+{
+    my $reverse = sub { my %p = @_;  return reverse $p{message}; };
+
+    my $dispatch = Log::Dispatch->new;
+
+    $dispatch->add( Log::Dispatch::Screen->new( name => 'foo',
+						min_level => 'warning',
+						max_level => 'alert',
+						stderr => 0,
+						callbacks => $reverse ) );
+
+    my $text;
+    tie *STDOUT, 'Test::Tie::STDOUT', \$text;
+    $dispatch->log( level => 'warning', message => 'esrever' );
+    untie *STDOUT;
+
+    result( $text eq 'reverse',
+	    "Log::Dispatch::Output callback did not reverse text as expected: $text\n" );
+}
+
+# 18:  Log::Dispatch::Output multiple callbacks
+{
+    my $reverse = sub { my %p = @_;  return reverse $p{message}; };
+    my $uc = sub { my %p = @_; return uc $p{message}; };
+
+    my $dispatch = Log::Dispatch->new;
+
+    $dispatch->add( Log::Dispatch::Screen->new( name => 'foo',
+						min_level => 'warning',
+						max_level => 'alert',
+						stderr => 0,
+						callbacks => [ $reverse, $uc ] ) );
+
+    my $text;
+    tie *STDOUT, 'Test::Tie::STDOUT', \$text;
+    $dispatch->log( level => 'warning', message => 'esrever' );
+    untie *STDOUT;
+
+    result( $text eq 'REVERSE',
+	    "Log::Dispatch callback did not reverse and uppercase text as expected: $text\n" );
+}
+
+# 19 - 106: Comprehensive test of new methods that match level names
+{
+    my %levels = map { $_ => $_ } ( qw( debug info notice warning err error crit critical alert emerg emergency ) );
+    @levels{ qw( err crit emerg ) } = ( qw( error critical emergency ) );
+
+    foreach my $allowed_level ( qw( debug info notice warning error critical alert emergency ) )
+    {
+	my $dispatch = Log::Dispatch->new;
+
+	$dispatch->add( Log::Dispatch::Screen->new( name => 'foo',
+						    min_level => $allowed_level,
+						    max_level => $allowed_level,
+						    stderr => 0 ) );
+
+	foreach my $test_level ( qw( debug info notice warning err error crit critical alert emerg emergency ) )
+	{
+	    my $text;
+	    tie *STDOUT, 'Test::Tie::STDOUT', \$text;
+	    $dispatch->$test_level( "$test_level test" );
+	    untie *STDOUT;
+
+	    if ( $levels{$test_level} eq $allowed_level )
+	    {
+		result( $text eq "$test_level test",
+			"Calling $test_level method should have sent message '$test_level test'\n" );
+	    }
+	    else
+	    {
+		result( $text eq '',
+			"Calling $test_level method should not have logged anything but we got '$text'\n" );
+	    }
+
+	    $text = '';
+	}
+    }
+}
+
 sub fake_test
 {
     my ($x, $pm) = @_;
